﻿using BPA.Common.Enums;
using BPA.Common.Enums.BizLog;

namespace BPA.Common.Infrastructure.BizLogs;

/// <summary>
/// 业务日志消息体
/// </summary>
public class BaseBizLogMsgBody : BaseMsgBody
{
    /// <summary>
    /// 业务日志类型
    /// </summary>
    public EnumBizLogType? EnumBizLogType { get; set; }

    #region Business

    /// <summary>
    /// 业务类型（业务节点）
    /// </summary>
    public EnumBusinessType EnumBusinessType { get; set; }

    /// <summary>
    /// 业务ID
    /// </summary>
#pragma warning disable CS8618
    public string BusinessId { get; set; }
#pragma warning restore CS8618

    #endregion

    #region Create

    /// <summary>
    /// 创建时间
    /// </summary>
    public DateTime? CreateDateTime { get; set; }

    /// <summary>
    /// 创建人
    /// </summary>
    public string? CreateBy { get; set; }

    /// <summary>
    /// 创建数据
    /// </summary>
    public Dictionary<string, object>? CreateData { get; set; }

    #endregion

    #region Update

    /// <summary>
    /// 更新时间
    /// </summary>
    public DateTime? UpdateDateTime { get; set; }

    /// <summary>
    /// 更新人
    /// </summary>
    public string? UpdateBy { get; set; }

    /// <summary>
    /// 更新之前的数据
    /// </summary>
    public Dictionary<string, object>? UpdateBeforeData { get; set; }

    /// <summary>
    /// 更新之后的数据
    /// </summary>
    public Dictionary<string, object>? UpdateAfterData { get; set; }

    #endregion

    #region Delete

    /// <summary>
    /// 删除时间
    /// </summary>
    public DateTime? DeleteDateTime { get; set; }

    /// <summary>
    /// 删除人
    /// </summary>
    public string? DeleteBy { get; set; }

    #endregion

    #region Query

    /// <summary>
    /// 查询
    /// </summary>
    public DateTime? QueryTime { get; set; }

    /// <summary>
    /// 查询人
    /// </summary>
    public string? QueryBy { get; set; }

    /// <summary>
    /// 查询条件数据
    /// </summary>
    public Dictionary<string, object>? QueryConditionData { get; set; }

    /// <summary>
    /// 查询基础信息
    /// </summary>
    public Dictionary<string, object>? QueryConditionBase { get; set; }

    #endregion
}