﻿using BPA.Component.Extensions;
using BPA.Component.RabbitMQClient.Base;
using Microsoft.Extensions.Logging;

namespace BPA.Common.Infrastructure.BizLogs;

public class BizLogProducer : BaseProducer<BaseBizLogMsgBody, BizLogProducer>
{
    private readonly ILogger<BizLogProducer> _logger;

    /// <summary>
    /// 构造
    /// </summary>
    /// <param name="logger"></param>
    public BizLogProducer(ILogger<BizLogProducer> logger) : base(logger)
    {
        _logger = logger;
    }

    /// <summary>
    /// 消息入队
    /// </summary>
    /// <param name="msgBody">消息体</param>
    /// <param name="routingKey">路由KEY</param>
    /// <param name="expiration">消息过期时间</param>
    public override void Enqueue(BaseBizLogMsgBody msgBody, string routingKey = null, long? expiration = null)
    {
        try
        {
            base.Enqueue(msgBody, routingKey, expiration);
        }
        catch (Exception e)
        {
            _logger.LogError(e, $"业务日志入列失败, {msgBody.ToJson()}");
        }
    }
}